class Platform():
    def __init__(self, id, name, is_brand_missing_from_name, platform_family_id, platform_family_name, model_no, storage_capacity, description, disambiguation, relevance, editions=[]):
        self.id = id
        self.name = name
        self.is_brand_missing_from_name = is_brand_missing_from_name
        self.platform_family_id = platform_family_id
        self.platform_family_name = platform_family_name
        self.model_no = model_no
        self.storage_capacity = storage_capacity
        self.description = description
        self.disambiguation = disambiguation
        self.relevance = relevance
        self.editions = []



from boardwatch_models.board import Board
from boardwatch_models.board_maker import BoardMaker
from boardwatch_models.game import Game
from boardwatch_models.listing import Listing
from boardwatch_models.platform import Platform
from boardwatch_models.platform_edition import PlatformEdition



class Board():
	boards = []

	def __init__(self, id, name, url, is_scraping_supported, listings=[]):
		self.id = id
		self.name = name
		self.url = url
		self.is_scraping_supported = is_scraping_supported
		self.listings = listings
		Board.boards.append(self)

	def summary(self):
		print('id: ' + str(self.id))
		print('name: ' + self.name)
		print('url: ' + self.url)
		print('is_scraping_supported: ' + str(self.is_scraping_supported))



class Game():
    def __init__(self, id, name, year_first_release, is_bootleg):
        self.id = id
        self.name = name
        self.year_first_release = year_first_release
        self.is_bootleg = is_bootleg


class PlatformEdition():
	def __init__(self, id, name, official_color, has_matte, has_transparency, has_gloss, note, image_url, colors=[]):
		self.id = id
		self.name = name
		self.official_color = official_color
		self.colors = colors
		self.has_matte = has_matte
		self.has_transparency = has_transparency
		self.has_gloss = has_gloss
		self.note = note
		self.image_url = image_url
		self.colors = colors



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="boardwatch-models",
    version="0.3.0",
    author="Nathan Alexander Page",
    author_email="nathanalexanderpage@gmail.com",
    description="Model classes for larger Boardwatch product",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/nathanalexanderpage/boardwatch_models",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Topic :: Games/Entertainment",
    ],
    python_requires='>=3.8',
)



class Listing():
	listings = []

	def __init__(self, id, native_id, title, body, url, seller_email, seller_phone, date_posted, date_scraped):
		self.id = id
		self.native_id = native_id
		self.title = title
		self.body = body
		self.url = url
		self.seller_email = seller_email
		self.seller_phone = seller_phone
		self.date_posted = date_posted
		self.date_scraped = date_scraped
		Listing.listings.append(self)
		